@@ -84,38 +84,3 @@ spPhylo=buildPhylo(aQ,snvF,add = NULL)
 plot(spPhylo$tree,cex=3,type = "c")
 
 
-###################################################
-### code chunk number 12: expands.Rnw:139-147
-###################################################
-#Patient and sample labels
-patient='ID_MRD_001';
-samples=c('_primPancreas','_metKidney','_metLung');
-output=patient;
-#The CBS files for each sample:
-cbs=as.list(paste(patient, samples,'.cbs',sep=""));
-#The SP files for each sample (previously calculated via runExPANdS-function):
-sps=as.list(paste(patient, samples,'.sps',sep=""));
-
-
-###################################################
-### code chunk number 13: expands.Rnw:150-161
-###################################################
-sampleGroup=list(cbs=cbs,sps=sps,labels=samples)
-tr=buildMultiSamplePhylo(sampleGroup,output,e = 0, plotF=0);
-##Tree tip color labels according to sample origin of SPs:
-jet <- colorRampPalette(c("#00007F", "blue", "#007FFF",
-            "cyan", "#7FFF7F", "yellow", "#FF7F00", "red", "#7F0000"))
-colmap = jet( length(sampleGroup$labels) )
-colors <- rep(colmap[1], each = length(tr$tip.label))
-for (i in 1: length(sampleGroup$labels) ) {
-     ii = grep(sampleGroup$labels[[i]], tr$tip.label)
-     colors[ii] = colmap[i]
-}
-
-
-###################################################
-### code chunk number 14: expands.Rnw:166-167
-###################################################
-plot(tr, tip.col = colors, cex = 0.9, type = "u")
-
-
